#!/usr/bin/env python

# this plugin requires gimp 1.1.x

from gimpfu import *

import os
import sys
import math

## specify your theme path here
themepath = os.environ["HOME"] + "/.themes/BlueIce"

## makes debugging easier
sys.stderr = open("/tmp/gimp.err", "w")
sys.stdout = open("/tmp/gimp.out", "w")

MODE_OUT = 0
MODE_IN = 1
MODE_BACK = 2
MODE_TRANS = 3

def load_template(name):
	filename = themepath + "/templates/" + name + ".xcf"
	img = pdb.gimp_xcf_load(0, filename, filename)
	return img, img.layers[-1]

def save_png(savename, img):
	filename = themepath + "/gtk/" + savename

	## apply all layer masks
	for layer in img.layers:
		pdb.gimp_image_remove_layer_mask(img, layer, 0)

	if len(img.layers) > 1:
		flat = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_IMAGE)
	else:
		flat = img.layers[0]

	pdb.file_png_save(img, flat, filename, filename, 0, 1, 9)

def standard_pixmap(savename, name, mode, color1, color2):
	img, background = load_template(name)

	width = pdb.gimp_image_width(img)
	height = pdb.gimp_image_width(img)

	x1 = width / 3.0
	y1 = height / 3.0
	x2 = width * 2.0
	y2 = height * 2.0

	pdb.gimp_selection_all(img)
	if mode == MODE_OUT:
		gimp.set_foreground(color1)
		gimp.set_background(color2)
		pdb.gimp_blend(background, FG_BG_RGB, NORMAL_MODE, CONICAL_SYMMETRIC, 100,
			       0, REPEAT_NONE, TRUE, 3, 1.0, x1, y1, x2, y2)
	elif mode == MODE_IN:
		gimp.set_foreground(color1)
		gimp.set_background(color2)
		pdb.gimp_blend(background, FG_BG_RGB, NORMAL_MODE, CONICAL_SYMMETRIC, 100,
			       0, REPEAT_NONE, TRUE, 3, 1.0, width - x1, height - y1, width - x2, height - y2)
	elif mode == MODE_BACK:
		gimp.set_background(color1)
		pdb.gimp_edit_fill(background)

	elif mode == MODE_TRANS:
		pass

	save_png(savename, img)
	pdb.gimp_image_delete(img)
	
def gtk_theme_blue_ice():
	normal_color = (148, 169, 178)
	prelight_color = (148, 169, 178)
	handle_prelight_color = (148, 178, 169)
	pressed_color = (148, 169, 178)
	select_color = (26, 26, 127)

#	normal_color = (148, 178, 169)
#	prelight_color = (148, 178, 169)
#	pressed_color = (148, 178, 169)

	insensitive_color = (169, 169, 169)

	back_color = (204, 204, 204)
	white_color = (255, 255, 255)
	black_color = (0, 0, 0)

	standard_pixmap("button_default.png", "frame_etched_in", MODE_BACK, back_color, white_color)
	standard_pixmap("button_normal.png", "frame_etched_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("button_prelight.png", "frame_in", MODE_OUT, prelight_color, white_color)
	standard_pixmap("button_pressed.png", "frame_in", MODE_IN, pressed_color, white_color)
	standard_pixmap("button_insensitive.png", "frame_etched_in", MODE_OUT, insensitive_color, white_color)

	standard_pixmap("check_in.png", "check_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("check_out.png", "check_out", MODE_OUT, normal_color, white_color)

	standard_pixmap("option_in.png", "option_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("option_out.png", "option_out", MODE_OUT, normal_color, white_color)

	standard_pixmap("arrow_up_normal.png", "arrow_up_out", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_up_prelight.png", "arrow_up_in", MODE_OUT, prelight_color, white_color)
	standard_pixmap("arrow_up_pressed.png", "arrow_up_in", MODE_IN, pressed_color, white_color)
	standard_pixmap("arrow_up_insensitive.png", "arrow_up_out", MODE_OUT, insensitive_color, white_color)
	standard_pixmap("arrow_up_etched_in.png", "arrow_up_etched_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_up_etched_out.png", "arrow_up_etched_out", MODE_OUT, prelight_color, white_color)

	standard_pixmap("arrow_down_normal.png", "arrow_down_out", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_down_prelight.png", "arrow_down_in", MODE_OUT, prelight_color, white_color)
	standard_pixmap("arrow_down_pressed.png", "arrow_down_in", MODE_IN, pressed_color, white_color)
	standard_pixmap("arrow_down_insensitive.png", "arrow_down_out", MODE_OUT, insensitive_color, white_color)
	standard_pixmap("arrow_down_etched_in.png", "arrow_down_etched_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_down_etched_out.png", "arrow_down_etched_out", MODE_OUT, prelight_color, white_color)

	standard_pixmap("arrow_left_normal.png", "arrow_left_out", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_left_prelight.png", "arrow_left_in", MODE_OUT, prelight_color, white_color)
	standard_pixmap("arrow_left_pressed.png", "arrow_left_in", MODE_IN, pressed_color, white_color)
	standard_pixmap("arrow_left_insensitive.png", "arrow_left_out", MODE_OUT, insensitive_color, white_color)
	standard_pixmap("arrow_left_etched_in.png", "arrow_left_etched_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_left_etched_out.png", "arrow_left_etched_out", MODE_OUT, prelight_color, white_color)

	standard_pixmap("arrow_right_flat.png", "arrow_right_flat", MODE_TRANS, back_color, white_color)
	standard_pixmap("arrow_right_normal.png", "arrow_right_out", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_right_prelight.png", "arrow_right_in", MODE_OUT, prelight_color, white_color)
	standard_pixmap("arrow_right_pressed.png", "arrow_right_in", MODE_IN, pressed_color, white_color)
	standard_pixmap("arrow_right_insensitive.png", "arrow_right_out", MODE_OUT, insensitive_color, white_color)
	standard_pixmap("arrow_right_etched_in.png", "arrow_right_etched_in", MODE_OUT, normal_color, white_color)
	standard_pixmap("arrow_right_etched_out.png", "arrow_right_etched_out", MODE_OUT, prelight_color, white_color)

	standard_pixmap("scrollbar_normal.png", "frame_out", MODE_OUT, normal_color, white_color)
	standard_pixmap("scrollbar_prelight.png", "frame_out", MODE_OUT, handle_prelight_color, white_color)

	standard_pixmap("extension_top.png", "extension_top", MODE_OUT, handle_prelight_color, white_color)
	standard_pixmap("gap_start_top.png", "gap_start_top", MODE_BACK, back_color, white_color)
	standard_pixmap("gap_end_top.png", "gap_end_top", MODE_BACK, back_color, white_color)
	standard_pixmap("gap_top.png", "gap_end_bottom", MODE_BACK, back_color, white_color)

	standard_pixmap("extension_bottom.png", "extension_top", MODE_OUT, handle_prelight_color, white_color)
	standard_pixmap("gap_start_bottom.png", "gap_start_bottom", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_end_bottom.png", "gap_end_bottom", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_bottom.png", "gap_end_top", MODE_BACK, back_color, white_color)

	standard_pixmap("extension_right.png", "extension_left", MODE_OUT, handle_prelight_color, white_color)
	standard_pixmap("gap_start_right.png", "gap_start_right", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_end_right.png", "gap_end_right", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_right.png", "gap_end_left", MODE_BACK, back_color, white_color)

	standard_pixmap("extension_left.png", "extension_left", MODE_OUT, handle_prelight_color, white_color)
	standard_pixmap("gap_start_left.png", "gap_start_left", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_end_left.png", "gap_end_left", MODE_TRANS, back_color, white_color)
	standard_pixmap("gap_left.png", "gap_end_right", MODE_BACK, back_color, white_color)

	standard_pixmap("frame_out.png", "frame_out", MODE_BACK, back_color, white_color)
	standard_pixmap("frame_in.png", "frame_in", MODE_BACK, back_color, white_color)

	standard_pixmap("frame_etched_out.png", "frame_etched_out", MODE_BACK, back_color, white_color)
	standard_pixmap("frame_etched_in.png", "frame_etched_in", MODE_BACK, back_color, white_color)

	standard_pixmap("frame_gap_start.png", "frame_gap_start", MODE_TRANS, back_color, white_color)
	standard_pixmap("frame_gap_end.png", "frame_gap_end", MODE_TRANS, back_color, white_color)

	standard_pixmap("flat_gray.png", "flat", MODE_BACK, back_color, white_color)
	standard_pixmap("flat_white.png", "flat", MODE_BACK, white_color, white_color)
	standard_pixmap("flat_selected.png", "flat", MODE_BACK, select_color, white_color)

register(
	"gtk_theme_blue_ice",
	"Generate buttons etc. for my gtk theme",
	"Generate buttons etc. for my gtk theme",
	"Martin Bauer",
	"Martin Bauer",
	"2000",
	"<Toolbox>/Xtns/Python-Fu/Gtk/BlueIce",
	"RGB*",
	[],
	[],
	gtk_theme_blue_ice)


main()

